===============
rstcheck-sphinx
===============

Builder extension for the sphinx documentation generator to check the source with rstcheck.

**This project is under heavy development and not yet ready for use!**

**The package on PyPI is empty.**
